@@ -63,7 +63,10 @@ def dump(cnf, overwrite, backup_file, section):
         use_cases_to_execute.append(DumpTeamsSecureUseCase(sdsecure, repository))
 
     if not section or 'policies' in section:
-        use_cases_to_execute.append(DumpPoliciesUseCase(sdsecure, repository))
+        if cnf.sdsecure.policy_v2:
+            use_cases_to_execute.append(DumpPoliciesUseCase(sdsecure, repository))
+        else:
+            use_cases_to_execute.append(DumpPoliciesUseCase(cnf.sdsecure_v1, repository))
 
     if not section or 'falco_rules' in section:
         use_cases_to_execute.append(DumpUserCreatedRulesUseCase(sdsecure, repository))
