@@ -69,7 +69,7 @@ def alerts(file_data, monitor: SdMonitorClient):
         if name in existing_alerts:
             if same_dict(alert, existing_alerts[name],
                          ['id', 'teamId', 'autoCreated',
-                          'notificationChannelIds', 'notificationCount', 'invalidMetrics',
+                          'notificationChannelNames', 'notificationCount', 'invalidMetrics',
                           'valid']):
                 print("      already exists, skip")
                 continue
@@ -219,7 +219,7 @@ def _add_falco_list(self, name, items, append=False):
         },
         "append": append,
     }
-    res = requests.post(self.url + '/api/secure/falco/lists', data=json.dumps(flist), headers=self.hdrs,
+    res = self.http.post(self.url + '/api/secure/falco/lists', data=json.dumps(flist), headers=self.hdrs,
                         verify=self.ssl_verify)
     return self._request_result(res)
 
