@@ -186,12 +186,6 @@ class RestoreAlertsUseCase(RestoreMonitorUseCase):
         if not ok:
             return False, res
 
-        # We update the notification channel ids of the file_data to restore in case
-        # the real IDs of the notification channels have changed
-        for alert in file_data:
-            alert['notificationChannelIds'] = sorted(
-                [nc['id'] for nc in res['notificationChannels'] if nc['name'] in alert['notificationChannelNames']])
-
         return restore.alerts(file_data, self._monitor)
 
 
@@ -211,12 +205,6 @@ class RemoveAndRestoreAlertsUseCase(RestoreMonitorUseCase):
         if not ok:
             return False, res
 
-        # We update the notification channel ids of the file_data to restore in case
-        # the real IDs of the notification channels have changed
-        for alert in file_data:
-            alert['notificationChannelIds'] = sorted(
-                [nc['id'] for nc in res['notificationChannels'] if nc['name'] in alert['notificationChannelNames']])
-
         return restore.alerts(file_data, self._monitor)
 
 
